@@ -1,3 +1,5 @@
+//! A command which prints out information about the process it runs in.
+
 #[cfg(not(windows))]
 use rustix::io;
 #[cfg(not(windows))]
@@ -15,6 +17,7 @@ fn main() -> io::Result<()> {
         println!("Linux hwcap: {:#x}, {:#x}", a, b);
     }
     println!("Page size: {}", page_size());
+    println!("Clock ticks/sec: {}", clock_ticks_per_second());
     println!("Uname: {:?}", uname());
     println!("Process group priority: {}", getpriority_pgrp(None)?);
     println!("Process priority: {}", getpriority_process(None)?);
