@@ -13,7 +13,7 @@ pub(crate) const fn in_addr_new(s_addr: u32) -> c::in_addr {
     c::in_addr { s_addr }
 }
 
-#[cfg(feature = "rustc-dep-of-std")]
+#[cfg(not(feature = "std"))]
 #[inline]
 pub(crate) const fn in6_addr_s6_addr(addr: c::in6_addr) -> [u8; 16] {
     unsafe { addr.in6_u.u6_addr8 }
@@ -21,7 +21,7 @@ pub(crate) const fn in6_addr_s6_addr(addr: c::in6_addr) -> [u8; 16] {
 
 // TODO: With Rust 1.55, we can use the above `in6_addr_s6_addr` definition
 // that uses a const-fn union access instead of doing a transmute.
-#[cfg(not(feature = "rustc-dep-of-std"))]
+#[cfg(not(not(feature = "std")))]
 #[inline]
 pub(crate) fn in6_addr_s6_addr(addr: c::in6_addr) -> [u8; 16] {
     unsafe { core::mem::transmute(addr) }
@@ -39,7 +39,7 @@ pub(crate) const fn sockaddr_in6_sin6_scope_id(addr: c::sockaddr_in6) -> u32 {
     addr.sin6_scope_id
 }
 
-#[cfg(feature = "rustc-dep-of-std")]
+#[cfg(not(feature = "std"))]
 #[inline]
 pub(crate) fn sockaddr_in6_sin6_scope_id_mut(addr: &mut c::sockaddr_in6) -> &mut u32 {
     &mut addr.sin6_scope_id
@@ -47,10 +47,10 @@ pub(crate) fn sockaddr_in6_sin6_scope_id_mut(addr: &mut c::sockaddr_in6) -> &mut
 
 #[inline]
 pub(crate) const fn sockaddr_in6_new(
-    sin6_family: linux_raw_sys::general::__kernel_sa_family_t,
+    sin6_family: c::sa_family_t,
     sin6_port: u16,
     sin6_flowinfo: u32,
-    sin6_addr: linux_raw_sys::general::in6_addr,
+    sin6_addr: c::in6_addr,
     sin6_scope_id: u32,
 ) -> c::sockaddr_in6 {
     c::sockaddr_in6 {
