@@ -2,6 +2,7 @@
 //! we can interpret the rest of a `sockaddr` produced by the kernel.
 #![allow(unsafe_code)]
 
+use super::super::c;
 use crate::net::{SocketAddrAny, SocketAddrStorage, SocketAddrUnix, SocketAddrV4, SocketAddrV6};
 use core::mem::size_of;
 
@@ -16,11 +17,11 @@ pub(crate) unsafe fn write_sockaddr(
     }
 }
 
-pub(crate) unsafe fn encode_sockaddr_v4(v4: &SocketAddrV4) -> linux_raw_sys::general::sockaddr_in {
-    linux_raw_sys::general::sockaddr_in {
-        sin_family: linux_raw_sys::general::AF_INET as _,
+pub(crate) unsafe fn encode_sockaddr_v4(v4: &SocketAddrV4) -> c::sockaddr_in {
+    c::sockaddr_in {
+        sin_family: c::AF_INET as _,
         sin_port: u16::to_be(v4.port()),
-        sin_addr: linux_raw_sys::general::in_addr {
+        sin_addr: c::in_addr {
             s_addr: u32::from_ne_bytes(v4.ip().octets()),
         },
         __pad: [0; 8_usize],
@@ -30,15 +31,15 @@ pub(crate) unsafe fn encode_sockaddr_v4(v4: &SocketAddrV4) -> linux_raw_sys::gen
 unsafe fn write_sockaddr_v4(v4: &SocketAddrV4, storage: *mut SocketAddrStorage) -> usize {
     let encoded = encode_sockaddr_v4(v4);
     core::ptr::write(storage.cast(), encoded);
-    size_of::<linux_raw_sys::general::sockaddr_in>()
+    size_of::<c::sockaddr_in>()
 }
 
-pub(crate) unsafe fn encode_sockaddr_v6(v6: &SocketAddrV6) -> linux_raw_sys::general::sockaddr_in6 {
-    linux_raw_sys::general::sockaddr_in6 {
-        sin6_family: linux_raw_sys::general::AF_INET6 as _,
+pub(crate) unsafe fn encode_sockaddr_v6(v6: &SocketAddrV6) -> c::sockaddr_in6 {
+    c::sockaddr_in6 {
+        sin6_family: c::AF_INET6 as _,
         sin6_port: u16::to_be(v6.port()),
         sin6_flowinfo: u32::to_be(v6.flowinfo()),
-        sin6_addr: linux_raw_sys::general::in6_addr {
+        sin6_addr: c::in6_addr {
             in6_u: linux_raw_sys::general::in6_addr__bindgen_ty_1 {
                 u6_addr8: v6.ip().octets(),
             },
@@ -50,7 +51,7 @@ pub(crate) unsafe fn encode_sockaddr_v6(v6: &SocketAddrV6) -> linux_raw_sys::gen
 unsafe fn write_sockaddr_v6(v6: &SocketAddrV6, storage: *mut SocketAddrStorage) -> usize {
     let encoded = encode_sockaddr_v6(v6);
     core::ptr::write(storage.cast(), encoded);
-    size_of::<linux_raw_sys::general::sockaddr_in6>()
+    size_of::<c::sockaddr_in6>()
 }
 
 unsafe fn write_sockaddr_unix(unix: &SocketAddrUnix, storage: *mut SocketAddrStorage) -> usize {
