@@ -8,6 +8,7 @@ mod fcntl;
 mod file;
 #[cfg(not(target_os = "wasi"))]
 mod flock;
+mod futimens;
 mod invalid_offset;
 mod long_paths;
 #[cfg(not(any(
@@ -23,9 +24,12 @@ mod makedev;
 mod mkdirat;
 mod mknodat;
 #[cfg(any(target_os = "android", target_os = "linux"))]
+mod openat;
+#[cfg(any(target_os = "android", target_os = "linux"))]
 mod openat2;
 mod readdir;
 mod renameat;
 #[cfg(not(any(target_os = "netbsd", target_os = "redox", target_os = "wasi")))]
 // not implemented in libc for netbsd yet
 mod statfs;
+mod utimensat;
